@@ -1,11 +1,11 @@
-;;; git-sync-mode.el --- Sync your git repositories on save  -*- lexical-binding: t; -*-
+;;; git-sync-mode.el --- Automatically commit and sync local changes  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2024-2025  Justin Barclay
 
 ;; Author: Justin Barclay <github@justincbarclay.ca>
 ;; Keywords: vc, convenience
-;; Package-Version: 0.5.0
-;; Package-Revision: v0.5.0-0-gabdb08a7fd26
+;; Package-Version: 20260101.2353
+;; Package-Revision: 9e602ebb0fa3
 ;; Homepage: https://github.com/justinbarclay/git-sync-mode
 ;; Package-Requires: ((emacs "29.1") (async-await))
 
@@ -35,7 +35,7 @@
 ;; 4. Automatically push, fast-forward, or rebase to fully sync.
 ;;
 ;; To ensure safety, `git-sync-mode` will only activate in repositories
-;; whose paths are included in the `git-sync-allow-list`. It also includes
+;; whose paths are included in the `git-sync-allow-list`.  It also includes
 ;; safeguards to prevent execution if the repository is in a special state
 ;; (e.g., during a merge or rebase) or if it is locked.
 
@@ -46,9 +46,14 @@
 (require 'ansi-color)
 (require 'subr-x)
 
+(eval-when-compile
+  (declare-function all-the-icons-octicon "ext:all-the-icons")
+  (declare-function nerd-icons-faicon "ext:nerd-icons")
+  (declare-function nerd-icons-octicon "ext:nerd-icons"))
+
 (defgroup git-sync
   nil
-  "Customizations for git-sync"
+  "Customizations for git-sync."
   :group 'vc)
 
 (defcustom git-sync-allow-list '()
@@ -123,7 +128,9 @@ Possible values:
 (defun git-sync--state-icon (state)
   "Return an icon for STATE if available."
   (cond
-   ((and (featurep 'nerd-icons) (fboundp 'nerd-icons-octicon))
+   ((and (featurep 'nerd-icons)
+         (fboundp 'nerd-icons-octicon)
+         (fboundp 'nerd-icons-faicon))
     (git-sync--nerd-icons-icon state))
    ((and (featurep 'all-the-icons) (fboundp 'all-the-icons-octicon))
     (git-sync--all-the-icons-icon state))
@@ -141,7 +148,7 @@ If BUFFER is non-nil, set the state in that buffer."
 
 (put 'git-sync-modeline-string 'risky-local-variable t)
 (defun git-sync--update-mode-line (state)
-  "Update `git-sync-modeline-string` for STATE and refresh mode line."
+  "Update `git-sync-modeline-string' for STATE and refresh mode line."
   (let ((icon (git-sync--state-icon state)))
     (setq git-sync-modeline-string
           (if icon
@@ -154,8 +161,8 @@ If BUFFER is non-nil, set the state in that buffer."
 (defun git-sync--commit-message ()
   (format "changes from %s on %s" (system-name) (current-time-string)))
 
-(defun git-sync--process-buffer (process _event)
-  "Colourizes the git-sync log buffer for `PROCESS' on `EVENT'."
+(defun git-sync--process-buffer (process)
+  "Colourizes the git-sync log buffer for PROCESS on EVENT."
   (let ((buf (process-buffer process)))
     (when (buffer-live-p buf)
       (let ((inhibit-read-only t))
@@ -165,8 +172,8 @@ If BUFFER is non-nil, set the state in that buffer."
           (unless (derived-mode-p 'special-mode)
             (special-mode)))))))
 
-(defun git-sync--process-filter (process string)
-  "Filter function for git-sync."
+(defun git-sync--process-filter (process output)
+  "Tracks most recent OUTPUT from PROCESS to be able to return from promise."
   (when (buffer-live-p (process-buffer process))
     (with-current-buffer (process-buffer process)
       (let ((moving (= (point) (process-mark process)))
@@ -174,15 +181,17 @@ If BUFFER is non-nil, set the state in that buffer."
         (save-excursion
           ;; Insert the text, advancing the process marker.
           (goto-char (process-mark process))
-          (insert string)
+          (insert output)
           (set-marker (process-mark process) (point)))
         (when moving
           (goto-char (process-mark process)))
-        (process-put process 'git-sync-output string)))))
+        (process-put process 'git-sync-output output)))))
 
 (defun git-sync--process-sentinel (process event)
-  "Sentinel function for git-sync."
-  (git-sync--process-buffer process event)
+  "Resolves the promise for PROCESS.
+
+EVENT is echoed to the user if the process fails."
+  (git-sync--process-buffer process)
   (with-current-buffer (process-buffer process)
     (when (memq (process-status process) '(exit signal))
       (let ((resolve (process-get process 'git-sync-resolve))
@@ -195,13 +204,13 @@ If BUFFER is non-nil, set the state in that buffer."
           (funcall reject (format "Command failed: %s" event)))))))
 
 (defun git-sync--execute-command (command dir &optional ignore-error)
-  "Execute `COMMAND' as a promise in the git-sync buffer.
+  "Execute COMMAND as a promise in the git-sync buffer.
 
-If `DIR' is provided, set `default-directory' to it for the command.
+If DIR is provided, set `default-directory' to it for the command.
 
-If `IGNORE-ERROR' is non-nil, resolve even if the command fails.
+If IGNORE-ERROR is non-nil, resolve even if the command fails.
 
-On success the promise returns the process-status for the command
+On success the promise returns the `process-status' for the command
 otherwise it rejects with the process event."
   ;; Turn off pager
   (make-local-variable 'process-environment)
@@ -222,7 +231,7 @@ otherwise it rejects with the process event."
 ;;;;;;;;;;
 
 (async-defun git-sync--get-upstream-branch (dir)
-  "Get the upstream branch for the current branch in `DIR`.
+  "Get the upstream branch for the current branch in DIR.
 
 If no upstream branch is found, return nil."
   (condition-case _err
@@ -235,7 +244,7 @@ If no upstream branch is found, return nil."
      nil)))
 
 (async-defun git-sync--get-sync-state (dir upstream)
-  "Get the sync state between HEAD and `UPSTREAM` in `DIR`."
+  "Get the sync state between HEAD and UPSTREAM in DIR."
   (let* ((output (string-trim
                   (await (git-sync--execute-command
                           (list "git" "rev-list" "--count" "--left-right" (concat upstream "...HEAD"))
@@ -250,7 +259,7 @@ If no upstream branch is found, return nil."
      (t (error "Could not determine sync state")))))
 
 (defun git-sync--repo-state (dir)
-  "Return the current git repository state in `DIR'."
+  "Return the current git repository state in DIR."
   (let* ((root (locate-dominating-file dir ".git"))
          (git-dir (and root (expand-file-name ".git" root))))
     (cond
@@ -268,20 +277,21 @@ If no upstream branch is found, return nil."
 ;;;;;;;;;;
 
 (async-defun git-sync--has-changes-p (dir)
-  "Return non-nil if git detected changes in `DIR'."
+  "Return non-nil if git detected changes in DIR."
   (let ((status (thread-first
                   '("git" "status" "--porcelain")
                   (git-sync--execute-command dir)
                   (await)
                   (string-trim)
                   (string-split "\n"))))
-    (any
-     (lambda (line)
-       (length> line 0))
-     status)))
+    (cl-reduce (lambda (any-p line)
+                 (or any-p
+                     (length> line 0)))
+               status
+               :initial-value nil)))
 
 (defun git-sync--index-locked-p (dir)
-  "Return non-nil if a .git/index.lock file exists in the repository root of `DIR'."
+  "Return non-nil if a .git/index.lock file exists in the repository root of DIR."
   (let* ((root (locate-dominating-file dir ".git"))
          (lock-file (and root (expand-file-name ".git/index.lock" root))))
     (and lock-file (file-exists-p lock-file))))
@@ -320,7 +330,7 @@ If no upstream branch is found, return nil."
 ;;;;;;;;;;
 
 (async-defun git-sync--execute (dir)
-  "Execute the git-sync process in `DIR`.
+  "Execute the git-sync process in DIR.
 
 The git sync process includes:
   1.  Committing local changes
@@ -330,7 +340,7 @@ The git sync process includes:
   4.  Determining sync state
   5.  Performing necessary actions based on sync state
       (fast-forward, rebase, push)."
-  (condition-case err
+  (condition-case _err
       (let (upstream)
         (when (await (git-sync--has-changes-p dir))
           (git-sync--set-state :committing)
@@ -373,7 +383,7 @@ The git sync process includes:
 ;; when opening up org-agenda and your agenda is made up of multiple
 ;; files from the same repo.
 (defun git-sync--lock (dir)
-  "Test if the mutex for `DIR' is set, if not set it.
+  "Test if the mutex for DIR is set, if not set it.
 
 Returns t if the mutex was successfully set, nil otherwise."
   (if (plist-get git-sync--locks
